function [Ke] = MatRigidezElCuadrilatero(Xe,nnode,pospg,pespg,Nxi,Neta) 
% [Ke,fe] = MatRigidezElCuadrilatero(Xe,nnode,pospg,pespg,N,Nxi,Neta) 
% Matriz de rigidez/conductividad Ke  
% elementales para la ecuacin del calor en 2D 
% 
% Xe:           coordenadas de los nodos del elemento 
% nnode:        nmero de nodos del elemento 
% pospg, pespg: posicin y pesos de los puntos de Gauss en el 
%               elemento de referencia 
% N,Nxi,Neta:   funciones de forma y derivadas (con coordenadas locales) 
%               en los puntos de Gauss del elemento de referencia
%%%%%%    Rodolfo Gallo

  Ke = zeros(nnode,nnode); 
% numero de puntos de Gauss 
  ngaus = size(pospg,1); 
 
% bucle en puntos de Gauss 
  for igaus = 1:ngaus   
      Nxi_igaus = Nxi(igaus,:);   
      Neta_igaus = Neta(igaus,:);   
      Jacob = [Nxi_igaus*(Xe(:,1))	Nxi_igaus*(Xe(:,2))   
               Neta_igaus*(Xe(:,1))	Neta_igaus*(Xe(:,2))]; 
      dvolu = pespg(igaus)*det(Jacob); 
      res = Jacob\[Nxi_igaus;Neta_igaus]; 
      f1 = res(1,:); 
      f2 = res(2,:); 
      Ke = Ke + (f1'*f1+f2'*f2)*dvolu;
  end 