function [K] = MatrizRigidezCuadrilatero(X,T) 
% [K] = Cremat(X,T,pospg,pespg,N,Nxi,Neta) 
% Matriz de rigidez/conductividad K 
% para la ecuacin del calor en 2D 
% 
% X:            coordenadas nodales 
% T:            conectividades (elementos) 
% pospg, pespg: posicin y pesos de los puntos de Gauss en el 
%               elemento de referencia 
% N,Nxi,Neta:   funciones de forma y derivadas con coordenadas locales 
%               en los puntos de Gauss del elemento de referencia 
%%%%%%    Rodolfo Gallo 
 
% numero de elementos y numero de nodos en cada elemento 
  [nelem,nnode] = size(T); 
% numero de nodos total  
  npoin = size(X,1); 
% Numero de puntos de Gauss
  ngaus = 4;
%
% Determinacion de la cuadratura y funciones de forma
  [pospg,pespg] = Cuadratura(ngaus);
  [N,Nxi,Neta] = FuncForm(pospg);
 
% Dimensionamiento 
K = zeros(npoin,npoin);   
% bucle en elementos 
  for ielem = 1:nelem 
    Te = T(ielem,:); 
    Xe = X(Te,:); % Xe: coordenadas de los nodos del elemento
    [Ke] = MatRigidezElCuadrilatero(Xe,nnode,pospg,pespg,Nxi,Neta); 
    K(Te,Te)= K(Te,Te)+Ke;  
    clear Ke; 
  end 
 