function [Fe] = VectorCargaElCuadrilatero(Xe,nnode,pospg,pespg,N,Nxi,Neta) 
% [Fe] = VectorCargaElCuadrilatero(Xe,nnode,pospg,pespg,N,Nxi,Neta) 
% Vector de carga o  trmino independiente fe (fuente) 
% elementales para la ecuacin del calor en 2D 
% 
% Xe:           coordenadas de los nodos del elemento 
% nnode:        nmero de nodos del elemento 
% pospg, pespg: posicin y pesos de los puntos de Gauss en el 
%               elemento de referencia 
% N,Nxi,Neta:   funciones de forma y derivadas (con coordenadas locales) 
%               en los puntos de Gauss del elemento de referencia
%%%%%%    Rodolfo Gallo 

 
  Fe = zeros(nnode,1); 
 
% numero de puntos de Gauss 
  ngaus = size(pospg,1); 
 
% bucle en puntos de Gauss 
  for igaus = 1:ngaus 
      N_igaus = N(igaus,:);  
      Nxi_igaus = Nxi(igaus,:);   
      Neta_igaus = Neta(igaus,:);   
      Jacob = [Nxi_igaus*(Xe(:,1))	Nxi_igaus*(Xe(:,2))   
               Neta_igaus*(Xe(:,1))	Neta_igaus*(Xe(:,2))]; 
      dvolu = pespg(igaus)*det(Jacob); 
      f_igaus = fuente(Isopar(Xe,N_igaus));
      Fe = Fe + N_igaus'*(f_igaus*dvolu); 
  end 